@@ -1,120 +1,11 @@
 # This R code contains a number of tests of the bain default function
 
-#==============================================================================================
-# compute c and f for an about equality constrained hypothesis with bain and with R")
-#==============================================================================================
-
-rm(list=ls())
-
-set.seed(124)
-x <- rnorm(20,-.3,.7)
-y <- rnorm(40,.2,1.3)
-
-#estimate of parameters
-estimate<-c(mean(x),mean(y))
-names(estimate)<-c("a","b")
-sampN<-c(20,40)
-cov1<-matrix(c(sd(x)^2/20),1,1)
-cov2<-matrix(c(sd(y)^2/40),1,1)
-covmat<-list(cov1,cov2)
-
-# testing an about equality constraint
-
-set.seed(100)
-y<-bain(estimate,"a-b > -.5 & b - a > -.5",n=sampN,Sigma=covmat,group_parameters=1,joint_parameters = 0)
-
-# x-y has prior mean zero
-# x-y has prior variance 1.155 and sd 1.07475
-
-sampc <- rnorm(100000,0,1.07475)
-for (i in 1:100000){
-  if (sampc[i] < .5 & sampc[i] > -.5) {sampc[i] <-1} else {sampc[i]<- 0}
-}
-
-test_that("bain default", {expect_equal(y$fit$Com[1],mean(sampc), tolerance = .01)})
-
-# x-y has posterior mean -.289637 and posterior variance .039 and sd .19728
-
-sampf <- rnorm(100000,-.289637,.19728)
-for (i in 1:100000){
-  if (sampf[i] < .5 & sampf[i] > -.5) {sampf[i] <-1} else {sampf[i]<- 0}
-}
-
-test_that("bain default", {expect_equal(y$fit$Fit[1], mean(sampf), tolerance = .004)})
-
-#==============================================================================================")
-# compute c and f for a range constrained hypothesis with bain and with R - a variation of the previous test")
-#==============================================================================================")
-
-# specify hypotheses for a range constraints and check
-
-set.seed(100)
-z<-bain(estimate,"a-b > -.3 & b - a > 0",n=sampN,Sigma=covmat,group_parameters=1,joint_parameters = 0)
-
-# x-y has prior mean zero
-# x-y has prior variance 1.155 and sd 1.0747
-
-sampcc <- rnorm(50000,0,1.0747)
-for (i in 1:50000){
-  if (sampcc[i] < 0 & sampcc[i] > -.3) {sampcc[i] <-1} else {sampcc[i]<- 0}
-}
-
-test_that("bain default", {expect_equal(z$fit$Com[1], mean(sampcc), tolerance = .01)})
-
-# x-y has posterior mean -.292 and posterior variance .039 and sd .1975
-
-sampff <- rnorm(50000,-.29,.1975)
-for (i in 1:50000){
-  if (sampff[i] < 0 & sampff[i] > -.3) {sampff[i] <-1} else {sampff[i]<- 0}
-}
-
-test_that("bain default", {expect_equal(z$fit$Fit[1], mean(sampff), tolerance = .01)})
-
-#==============================================================================================")
-# compute c and f for a range constrained hypothesis where range is determined by another parameter")
-#==============================================================================================")
-
-rm(list=ls())
-
-#estimate of parameters
-estimate<-c(2,4)
-names(estimate)<-c("a","b")
-sampN<-c(20,40)
-cov1<-matrix(1,1,1)
-cov2<-matrix(1,1,1)
-covmat<-list(cov1,cov2)
-
-# specify hypotheses for a range constraints and check
-
-set.seed(100)
-y<-bain(estimate,"a  > -b & a < b",n=sampN,Sigma=covmat,group_parameters=1,joint_parameters = 0)
-
-# a and b have prior mean 0
-# a has prior variance 20 sd 4.47  and b has prior variance 40 sd 6.32
-
-countc <- 0
-sampa <- rnorm(500000,0,4.472136)
-sampb <- rnorm(500000,0,6.324555)
-for (i in 1:500000){
-  if (sampa[i] > -sampb[i] & sampa[i] < sampb[i]) {countc = 1/500000 + countc}
-}
-
-test_that("bain default", {expect_equal(y$fit$Com[1], countc, tolerance = .004)})
-
-countf <- 0
-sampa <- rnorm(50000,2,1)
-sampb <- rnorm(50000,4,1)
-for (i in 1:50000){
-  if (sampa[i] > -sampb[i] & sampa[i] < sampb[i]) {countf = 1/50000 + countf}
-}
-
-test_that("bain default", {expect_equal(y$fit$Fit[1], countf, tolerance = .01)})
 
 #========================================================================================")
 # compute c=, f=, and f>|= for an hypothesis with 1 = and 1 > restriction with Bain and R")
 #========================================================================================")
 
-rm(list=ls())
+
 
 estimate <- c(1,1)
 names(estimate)<-c("a", "b")
@@ -149,7 +40,7 @@ test_that("bain default", {expect_equal(y$fit$Com_in[1], .5, tolerance = .01)})
 # a straightforward variation of the previous test")
 #========================================================================================")
 
-rm(list=ls())
+
 
 estimate <- c(0,4)
 names(estimate)<-c("a", "b")
@@ -185,7 +76,7 @@ test_that("bain default", {expect_equal(y$fit$Com_in[1], .5, tolerance = .01)})
 # and complexity for three hypotheses using Bain, R, and mentally.")
 #========================================================================================")
 
-rm(list=ls())
+
 
 estimate <- c(0,0,0,0,0,0)
 names(estimate)<-c("a", "b","c", "d", "e", "f")
@@ -213,7 +104,7 @@ test_that("bain default", {expect_equal(y$fit$Com_in, c(1,.125,.015625,NA))})
 # Compute fit of 0 and complexity of 1/6 for an hypothesis that is really wrong")
 #========================================================================================")
 
-rm(list=ls())
+
 
 estimate <- c(-1,0,1)
 names(estimate)<-c("a", "b","c")
@@ -231,7 +122,7 @@ test_that("bain default", {expect_equal(y$fit$Com[1], .167, tolerance = .01)})
 # the same example without redundant constraints renders similar results")
 #========================================================================================")
 
-rm(list=ls())
+
 
 estimate <- c(0, 0, 0)
 names(estimate)<-c("a", "b","c")
@@ -249,7 +140,7 @@ test_that("bain default", {expect_equal(y$fit$Com, c(.125,.125,NA),tolerance = .
 # used to compute the prior covariance matrix")
 #========================================================================================")
 
-rm(list=ls())
+
 
 estimate <- c(.2,0)
 names(estimate)<-c("a", "b")
@@ -268,7 +159,7 @@ test_that("bain default", {expect_equal(as.vector(y$prior), c(4,0,0,8))})
 #  using an ancova to test the reconstruction of the posterior covariance matrix")
 #========================================================================================")
 
-rm(list=ls())
+
 
 # select the appropriate columns from the data file sesame.txt and center the covariates
 
@@ -296,7 +187,7 @@ test_that("bain default", {expect_equal(as.vector(y$posterior), as.vector(vcov(a
 # of the prior covariance matrix")
 #========================================================================================")
 
-rm(list=ls())
+
 
 estimate<-c(0,0,0,0,0,0,0)
 names(estimate) <- c("a", "b", "c", "d", "e", "c1", "c2")
@@ -357,7 +248,7 @@ test_that("bain default", {expect_equal(invcov[5,7], invcov57)})
 # SAME AS ABOVE BUT NOW DIFFERENT N AND NONDIAGONAL COVS")
 #========================================================================================")
 
-rm(list=ls())
+
 
 estimate<-c(0,0,0,0,0,0,0)
 names(estimate) <- c("a", "b", "c", "d", "e", "c1", "c2")
@@ -426,7 +317,7 @@ test_that("bain default", {expect_equal(invcov[5,7], invcov57)})
 # using stylized tests")
 #========================================================================================")
 
-rm(list=ls())
+
 
 estimate<-c(0,0,0)
 names(estimate) <- c("a", "b", "c")
@@ -461,7 +352,7 @@ test_that("bain default", {expect_equal(x$fit$Com, c(0.003874745,NA),tolerance =
 # using stylized tests to check the use of scalar multiplyers and additive constants")
 #========================================================================================")
 
-rm(list=ls())
+
 
 estimate<-c(0,1,2)
 names(estimate) <- c("a", "b", "c")
@@ -494,16 +385,12 @@ test_that("bain default", {expect_equal(y$fit$Com[1], propc,tolerance = .01)})
 # same as the previous test but now constants split in two parts")
 #========================================================================================")
 
-rm(list=ls())
-
 estimate<-c(0,1,2)
 names(estimate) <- c("a", "b", "c")
 sampN <- 100
 covariance <- matrix(c(1,0,0,0,1,0,0,0,1),nrow=3,ncol=3)
-
 set.seed(199)
-y<-bain(estimate,"3*a + .5 + .5 > 2*b -1 + 1> c -1.5 -.5",n=sampN,Sigma=covariance,group_parameters=0,joint_parameters = 3)
-
+y<-bain(estimate,"3a + .5 + .5 > 2b -1 + 1> c -1.5 -.5",n=sampN,Sigma=covariance,group_parameters=0,joint_parameters = 3)
 a <- rnorm(100000,0,1)
 b <- rnorm(100000,1,1)
 c <- rnorm(100000,2,1)
@@ -512,7 +399,6 @@ for (i in 1:100000){
   if (3 * a[i] + 1 > 2 * b[i] & 2 * b[i] > c[i]-2) {propf <- propf + 1/100000}
 }
 test_that("bain default", {expect_equal(y$fit$Fit[1], propf,tolerance = .01)})
-
 a <- rnorm(100000,-1/3,50)
 b <- rnorm(100000,0,50)
 c <- rnorm(100000,2,50)
